@@ -1,7 +1,7 @@
 jags <- function (data, inits, parameters.to.save, model.file = "model.bug", 
   n.chains = 3, n.iter = 2000, n.burnin = floor(n.iter/2), 
   n.thin = max(1, floor((n.iter - n.burnin)/n.sims)), n.sims = 1000, 
-  n.adapt = 1000, DIC = FALSE, working.directory = NULL, 
+  DIC = FALSE, working.directory = NULL, 
   refresh = n.iter/50, progress.bar="text") 
 {
   
@@ -45,17 +45,29 @@ jags <- function (data, inits, parameters.to.save, model.file = "model.bug",
   if(is.null(inits)){
     m <- jags.model(model.file, data = data, n.chains = n.chains, 
       n.adapt = 0)
-    adapt(m, n.iter =  n.adapt, by = refresh, progress.bar = progress.bar) 
+    if(n.burnin>0){
+      n.adapt <- n.burnin
+    }
+    if(n.burnin==0){
+      n.adapt <- 100
+    }
+    adapt(m, n.iter = n.adapt, by = refresh, progress.bar = progress.bar) 
   }
   else{ 
     m <- jags.model(model.file, data = data, inits=inits, n.chains = n.chains, 
       n.adapt = 0)
-    adapt(m, n.iter =  n.adapt, by = refresh, progress.bar = progress.bar) 
+    if(n.burnin>0){
+      n.adapt <- n.burnin
+    }
+    if(n.burnin==0){
+      n.adapt <- 100
+    }
+    adapt(m, n.iter = n.adapt, by = refresh, progress.bar = progress.bar) 
   }
   
-  if(n.burnin > 0){
-    update(m, n.burnin, by = refresh, progress.bar = progress.bar)
-  }
+#  if(n.burnin > 0){
+#    update(m, n.burnin, by = refresh, progress.bar = progress.bar)
+#  }
   
   samples <- coda.samples(model = m, variable.names = parameters.to.save, 
       n.iter = (n.iter-n.burnin), thin = n.thin, by = refresh, 
